[aes] Update naming from sanity to smoke

Signed-off-by: Cindy Chen <chencindy@google.com>
diff --git a/hw/ip/aes/data/aes_testplan.hjson b/hw/ip/aes/data/aes_testplan.hjson
index 80ffdac..54868ba 100644
--- a/hw/ip/aes/data/aes_testplan.hjson
+++ b/hw/ip/aes/data/aes_testplan.hjson
@@ -22,25 +22,25 @@
       tests: ["aes_wake_up"]
     }
     {
-      name: sanity
+      name: smoke
       desc: '''
            Encrypt a plain text read it back - decrypt and compare to input but use reference model to compare after both encryption and decryption.'''
       milestone: V1
-      tests: ["aes_sanity"]
+      tests: ["aes_smoke"]
     }
     {
       name: algorithm
       desc: '''
            Compare cypher text from DUT with the output of a C model using same key and data.'''
            milestone: V2
-      tests: ["aes_sanity", "aes_config_error"]
+      tests: ["aes_smoke", "aes_config_error"]
     }
     {
       name: key_length
       desc: '''
            Randomly select key length to verify all supported key lengths are working.'''
            milestone: V2
-      tests: ["aes_stress", "aes_sanity", "aes_config_error"]
+      tests: ["aes_stress", "aes_smoke", "aes_config_error"]
     }
     {
       name: back2back
@@ -63,7 +63,7 @@
         Run multiple messages in a random mix of encryption / decryption.
         Each message should select its mode randomly.'''
       milestone: V2
-      tests: ["aes_stress", "aes_sanity", "aes_config_error"]
+      tests: ["aes_stress", "aes_smoke", "aes_config_error"]
     }
     {
       name: failure_test
diff --git a/hw/ip/aes/doc/checklist.md b/hw/ip/aes/doc/checklist.md
index 9d65704..8159cf2 100644
--- a/hw/ip/aes/doc/checklist.md
+++ b/hw/ip/aes/doc/checklist.md
@@ -118,11 +118,11 @@
 Testbench     | [SIM_RAL_MODEL_GEN_AUTOMATED][]       | Done        |
 Testbench     | [CSR_CHECK_GEN_AUTOMATED][]           | Done        |
 Testbench     | [TB_GEN_AUTOMATED][]                  | N/A         |
-Tests         | [SIM_SANITY_TEST_PASSING][]           | Done        |
+Tests         | [SIM_SMOKE_TEST_PASSING][]            | Done        |
 Tests         | [SIM_CSR_MEM_TEST_SUITE_PASSING][]    | Done        |
 Tests         | [FPV_MAIN_ASSERTIONS_PROVEN][]        | N/A         |
 Tool Setup    | [SIM_ALT_TOOL_SETUP][]                | Done        | Xcelium (signoff), VCS (alt)
-Regression    | [SIM_SANITY_REGRESSION_SETUP][]       | Done        |
+Regression    | [SIM_SMOKE_REGRESSION_SETUP][]        | Done        |
 Regression    | [SIM_NIGHTLY_REGRESSION_SETUP][]      | Done        |
 Regression    | [FPV_REGRESSION_SETUP][]              | N/A         |
 Coverage      | [SIM_COVERAGE_MODEL_ADDED][]          | Done        |
@@ -141,11 +141,11 @@
 [SIM_RAL_MODEL_GEN_AUTOMATED]:        {{<relref "/doc/project/checklist.md#sim_ral_model_gen_automated" >}}
 [CSR_CHECK_GEN_AUTOMATED]:            {{<relref "/doc/project/checklist.md#csr_check_gen_automated" >}}
 [TB_GEN_AUTOMATED]:                   {{<relref "/doc/project/checklist.md#tb_gen_automated" >}}
-[SIM_SANITY_TEST_PASSING]:            {{<relref "/doc/project/checklist.md#sim_sanity_test_passing" >}}
+[SIM_SMOKE_TEST_PASSING]:             {{<relref "/doc/project/checklist.md#sim_smoke_test_passing" >}}
 [SIM_CSR_MEM_TEST_SUITE_PASSING]:     {{<relref "/doc/project/checklist.md#sim_csr_mem_test_suite_passing" >}}
 [FPV_MAIN_ASSERTIONS_PROVEN]:         {{<relref "/doc/project/checklist.md#fpv_main_assertions_proven" >}}
 [SIM_ALT_TOOL_SETUP]:                 {{<relref "/doc/project/checklist.md#sim_alt_tool_setup" >}}
-[SIM_SANITY_REGRESSION_SETUP]:        {{<relref "/doc/project/checklist.md#sim_sanity_regression_setup" >}}
+[SIM_SMOKE_REGRESSION_SETUP]:         {{<relref "/doc/project/checklist.md#sim_smoke_regression_setup" >}}
 [SIM_NIGHTLY_REGRESSION_SETUP]:       {{<relref "/doc/project/checklist.md#sim_nightly_regression_setup" >}}
 [FPV_REGRESSION_SETUP]:               {{<relref "/doc/project/checklist.md#fpv_regression_setup" >}}
 [SIM_COVERAGE_MODEL_ADDED]:           {{<relref "/doc/project/checklist.md#sim_coverage_model_added" >}}
diff --git a/hw/ip/aes/doc/dv_plan/index.md b/hw/ip/aes/doc/dv_plan/index.md
index 18a3024..db45eea 100644
--- a/hw/ip/aes/doc/dv_plan/index.md
+++ b/hw/ip/aes/doc/dv_plan/index.md
@@ -106,9 +106,9 @@
 ## Building and running tests
 We are using our in-house developed [regression tool]({{< relref "hw/dv/tools/README.md" >}}) for both building and running our tests and regressions.
 Please take a look at the link for detailed information on the usage, capabilities, features and known issues.
-Here's how to run a basic sanity test:
+Here's how to run a smoke test:
 ```console
-$ $REPO_TOP/util/dvsim/dvsim.py $REPO_TOP/hw/ip/aes/dv/aes_sim_cfg.hjson -i aes_sanity
+$ $REPO_TOP/util/dvsim/dvsim.py $REPO_TOP/hw/ip/aes/dv/aes_sim_cfg.hjson -i aes_smoke
 ```
 Here's how to run a basic test without DPI calls:
 ```console
diff --git a/hw/ip/aes/dv/aes_sim_cfg.hjson b/hw/ip/aes/dv/aes_sim_cfg.hjson
index e3414ba..1be8c25 100644
--- a/hw/ip/aes/dv/aes_sim_cfg.hjson
+++ b/hw/ip/aes/dv/aes_sim_cfg.hjson
@@ -58,8 +58,8 @@
     }
 
     {
-      name: aes_sanity
-      uvm_test: aes_sanity_test
+      name: aes_smoke
+      uvm_test: aes_smoke_test
       uvm_test_seq: aes_stress_vseq
     }
     {
@@ -82,8 +82,8 @@
   // List of regressions.
   regressions: [
     {
-      name: sanity
-      tests: ["aes_sanity"]
+      name: smoke
+      tests: ["aes_smoke"]
     }
     {
       name: failure
diff --git a/hw/ip/aes/dv/tests/aes_test.core b/hw/ip/aes/dv/tests/aes_test.core
index e77a2a5..1d37d8b 100644
--- a/hw/ip/aes/dv/tests/aes_test.core
+++ b/hw/ip/aes/dv/tests/aes_test.core
@@ -12,7 +12,7 @@
       - aes_test_pkg.sv
       - aes_base_test.sv: {is_include_file: true}
       - aes_wake_up_test.sv: {is_include_file: true}
-      - aes_sanity_test.sv: {is_include_file: true}
+      - aes_smoke_test.sv: {is_include_file: true}
       - aes_stress_test.sv: {is_include_file: true}
       - aes_b2b_test.sv: {is_include_file: true}
       - aes_config_error_test.sv: {is_include_file: true}
diff --git a/hw/ip/aes/dv/tests/aes_test_pkg.sv b/hw/ip/aes/dv/tests/aes_test_pkg.sv
index b51c3e8..3883156 100644
--- a/hw/ip/aes/dv/tests/aes_test_pkg.sv
+++ b/hw/ip/aes/dv/tests/aes_test_pkg.sv
@@ -19,7 +19,7 @@
   // package sources
   `include "aes_base_test.sv"
   `include "aes_wake_up_test.sv"
-  `include "aes_sanity_test.sv"
+  `include "aes_smoke_test.sv"
   `include "aes_stress_test.sv"
   `include "aes_b2b_test.sv"
   `include "aes_config_error_test.sv"
diff --git a/hw/ip/aes/dv/tests/aes_sanity_test.sv b/hw/ip/aes/dv/tests/aes_smoke_test.sv
similarity index 87%
rename from hw/ip/aes/dv/tests/aes_sanity_test.sv
rename to hw/ip/aes/dv/tests/aes_smoke_test.sv
index 3836312..2fb7705 100644
--- a/hw/ip/aes/dv/tests/aes_sanity_test.sv
+++ b/hw/ip/aes/dv/tests/aes_smoke_test.sv
@@ -2,9 +2,9 @@
 // Licensed under the Apache License, Version 2.0, see LICENSE for details.
 // SPDX-License-Identifier: Apache-2.0
 
-class aes_sanity_test extends aes_base_test;
+class aes_smoke_test extends aes_base_test;
 
-  `uvm_component_utils(aes_sanity_test)
+  `uvm_component_utils(aes_smoke_test)
   `uvm_component_new
 
 
@@ -19,7 +19,7 @@
 //    the feature below is waiting in anther PR
 //    cfg.zero_delay_pct           = 100;
 
-    cfg.error_types              = 0;     // no errors in sanity test
+    cfg.error_types              = 0;     // no errors in smoke test
     cfg.num_messages_min         = 2;
     cfg.num_messages_max         = 2;
     // message related knobs
@@ -49,4 +49,4 @@
 
     `DV_CHECK_RANDOMIZE_FATAL(cfg)
   endfunction
-endclass : aes_sanity_test
+endclass : aes_smoke_test